test_that("boxscore() returns non-empty data.frame", {
  skip_if_offline()
  test <- boxscore()
  expect_true(is.data.frame(test) && nrow(test) > 0)
})

test_that("boxscore(0) returns message and empty data.frame", {
  skip_if_offline()
  expect_message(
    test <- boxscore(0),
    'Invalid argument\\(s\\); refer to help file\\.'
  )
  expect_true(is.data.frame(test) && nrow(test) == 0)
})
